Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(898)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_view.h

Issue 11418043: Remove TabContents from OmniboxEditController and friends. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: cros Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/location_bar_view.h
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.h b/chrome/browser/ui/views/location_bar/location_bar_view.h
index 3fb9a382522257f2a3bf801be52f9fbf8722e345..1b480faea24f61c792e61fc7c3a888afb33bff06 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.h
@@ -47,7 +47,6 @@ class PageActionImageView;
class Profile;
class SelectedKeywordView;
class StarView;
-class TabContents;
class TemplateURLService;
class WebIntentsButtonView;
class ZoomView;
@@ -99,8 +98,8 @@ class LocationBarView : public LocationBar,
class Delegate {
public:
- // Should return the current tab contents.
- virtual TabContents* GetTabContents() const = 0;
+ // Should return the current web contents.
+ virtual content::WebContents* GetWebContents() const = 0;
// Returns the InstantController, or NULL if there isn't one.
virtual InstantController* GetInstant() = 0;
@@ -282,7 +281,7 @@ class LocationBarView : public LocationBar,
virtual gfx::Image GetFavicon() const OVERRIDE;
virtual string16 GetTitle() const OVERRIDE;
virtual InstantController* GetInstant() OVERRIDE;
- virtual TabContents* GetTabContents() const OVERRIDE;
+ virtual content::WebContents* GetWebContents() const OVERRIDE;
// Overridden from views::View:
virtual std::string GetClassName() const OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698